@@ -1,5 +1,6 @@
 import pandas as pd
 def topsis(df,weights,impacts):
+    df1=pd.DataFrame()
     df1=df.copy()
     vjp=[]
     vjn=[]
@@ -19,7 +20,6 @@ def topsis(df,weights,impacts):
         else:
             vjn.append(max(df.iloc[:,i]))
             vjp.append(min(df.iloc[:,i]))
-# print(vjp,vjn)
     for i in range(r):
         df.loc[i,'sj+']=sum((df.iloc[i,1:c]-vjp)**2)**0.5
     for i in range(r):
